@@ -41,10 +41,46 @@ AQSys.mathDesc <- function(mathDesc) {
         P2 <- CoefSET[2]
         P3 <- CoefSET[3]
         P4 <- CoefSET[4]
-        # tello's equation
+        # tang's equation
         exp(P1 + P2 * (XC ^ (0.5)) + P3 * XC + P4 * (XC ^ 2))
       }
     },
+    "chen" = {
+      Fn <- function(CoefSET, XC) {
+        # equation's parameters
+        P1 <- CoefSET[1]
+        P2 <- CoefSET[2]
+        P3 <- CoefSET[3]
+        P4 <- CoefSET[4]
+        P5 <- CoefSET[5]
+        # chen's equation
+        exp(P1 + P2 * (XC ^ (0.5)) + P3 * XC + P4 * (XC ^ 2)+ P5 * (XC ^ 3))
+      }
+    },
+    # "xie" = {
+    #   Fn <- function(CoefSET, XC) {
+    #     # equation's parameters
+    #     P1 <- CoefSET[1]
+    #     P2 <- CoefSET[2]
+    #     P3 <- CoefSET[3]
+    #     P4 <- CoefSET[4]
+    #     P5 <- CoefSET[5]
+    #     # xie's equation
+    #     P1 * exp(- (Xc/P2)) + P3 * exp(- (Xc/P4)) + P5
+    #   }
+    # },
+    # model needs more data than just the phase diagram
+    # "xueqiao" = {
+    #   Fn <- function(CoefSET, XC) {
+    #     # equation's parameters
+    #     P1 <- CoefSET[1]
+    #     P2 <- CoefSET[2]
+    #     P3 <- CoefSET[3]
+    #     P4 <- CoefSET[4]
+    #     # xueqiao's equation
+    #     P1 * (-log(P2 * (XC / P3) + P4) / P2)
+    #   }
+    # },
     # if user selects an option not available, it triggers an error
     # (check AQSys.err.R for details)
     AQSys.err("0")
@@ -53,23 +89,27 @@ AQSys.mathDesc <- function(mathDesc) {
   return(Fn)
 }
 ####################################################################################################################
-# @rdname AQSysList
-# @export AQSysList
-# @title Aqueous Systems Descriptors already implemented
-# @description The function returns a list of all mathematical descriptors available at the time.
-# @param npars Logic option to return a List variable containing the number of required parameters for each equation.
+#' @rdname AQSysList
+#' @export AQSysList
+#' @title Aqueous Systems Descriptors already implemented
+#' @description The function returns a list of all mathematical descriptors available at the time.
+#' @param npars Logic option to return a List variable containing the number of required parameters for each equation.
 AQSysList <- function(npars=FALSE) {
   # a new entry in updte must be added for each new equation implemmented in AQSys.mathDesc()
   # updte entries' name must match AQSys.mathDesc switch options
+  model_list <- list(
+    "merchuk" = 3,
+    "murugesan" = 3,
+    "tello" = 3,
+    "tang" = 4,
+    "chen" = 5
+    # ,"xie" = 5,
+    # "xueqiao" = 4
+  )
   updte <- if(npars) {
-    list(
-      "merchuk" = 3,
-      "murugesan" = 3,
-      "tello" = 3,
-      "tang" = 4
-    )
+    model_list
   } else {
-    list("merchuk", "murugesan", "tello", "tang")
+    names(model_list)
   }
   # return list
   return(updte)
